@@ -43,12 +43,12 @@ class SearchController < ApplicationController
     begin; offset = params[:offset].to_time if params[:offset]; rescue; end
     
     # quick jump to an issue
-    if @question.match(/^#?(\d+)$/) && Issue.visible.find_by_id($1)
+    if @question.match(/^#?(\d+)$/) && Issue.visible.find_by_id($1.to_i)
       redirect_to :controller => "issues", :action => "show", :id => $1
       return
     end
     
-    @object_types = %w(issues news documents changesets wiki_pages messages projects)
+    @object_types = Redmine::Search.available_search_types.dup
     if projects_to_search.is_a? Project
       # don't search projects
       @object_types.delete('projects')
@@ -67,16 +67,14 @@ class SearchController < ApplicationController
     
     if !@tokens.empty?
       # no more than 5 tokens to search for
-      @tokens.slice! 5..-1 if @tokens.size > 5
-      # strings used in sql like statement
-      like_tokens = @tokens.collect {|w| "%#{w.downcase}%"}      
+      @tokens.slice! 5..-1 if @tokens.size > 5  
       
       @results = []
       @results_by_type = Hash.new {|h,k| h[k] = 0}
       
       limit = 10
       @scope.each do |s|
-        r, c = s.singularize.camelcase.constantize.search(like_tokens, projects_to_search,
+        r, c = s.singularize.camelcase.constantize.search(@tokens, projects_to_search,
           :all_words => @all_words,
           :titles_only => @titles_only,
           :limit => (limit+1),
