@@ -104,4 +104,15 @@ module CustomFieldsHelper
   def custom_field_formats_for_select
     Redmine::CustomFieldFormat.as_select
   end
+  
+  # Renders the custom_values in api views
+  def render_api_custom_values(custom_values, api)
+    api.array :custom_fields do
+      custom_values.each do |custom_value|
+        api.custom_field :id => custom_value.custom_field_id, :name => custom_value.custom_field.name do
+          api.value custom_value.value
+        end
+      end
+    end unless custom_values.empty?
+  end
 end
