@@ -17,6 +17,11 @@
 
 class JournalObserver < ActiveRecord::Observer
   def after_create(journal)
-    Mailer.deliver_issue_edit(journal) if Setting.notified_events.include?('issue_updated')
+    if Setting.notified_events.include?('issue_updated') ||
+        (Setting.notified_events.include?('issue_note_added') && journal.notes.present?) ||
+        (Setting.notified_events.include?('issue_status_updated') && journal.new_status.present?) ||
+        (Setting.notified_events.include?('issue_priority_updated') && journal.new_value_for('priority_id').present?)
+      Mailer.deliver_issue_edit(journal)
+    end
   end
 end
