@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.dirname(__FILE__) + '/../test_helper'
+require File.expand_path('../../test_helper', __FILE__)
 require 'attachments_controller'
 
 # Re-raise errors caught by the controller.
@@ -95,7 +95,7 @@ class AttachmentsControllerTest < ActionController::TestCase
       post :destroy, :id => 1
     end
     # no referrer
-    assert_redirected_to 'projects/ecookbook'
+    assert_redirected_to '/projects/ecookbook'
     assert_nil Attachment.find_by_id(1)
     j = issue.journals.find(:first, :order => 'created_on DESC')
     assert_equal 'attachment', j.details.first.property
