@@ -1,24 +1,43 @@
-require File.dirname(__FILE__) + '/../test_helper'
+require File.expand_path('../../test_helper', __FILE__)
 
 class GanttsControllerTest < ActionController::TestCase
   fixtures :all
 
   context "#gantt" do
     should "work" do
+      i2 = Issue.find(2)
+      i2.update_attribute(:due_date, 1.month.from_now)
+      
       get :show, :project_id => 1
       assert_response :success
       assert_template 'show.html.erb'
       assert_not_nil assigns(:gantt)
-      events = assigns(:gantt).events
-      assert_not_nil events
       # Issue with start and due dates
       i = Issue.find(1)
       assert_not_nil i.due_date
-      assert events.include?(Issue.find(1))
-      # Issue with without due date but targeted to a version with date
+      assert_select "div a.issue", /##{i.id}/
+      # Issue with on a targeted version should not be in the events but loaded in the html
       i = Issue.find(2)
-      assert_nil i.due_date
-      assert events.include?(i)
+      assert_select "div a.issue", /##{i.id}/
+    end
+    
+    should "work without issue due dates" do
+      Issue.update_all("due_date = NULL")
+      
+      get :show, :project_id => 1
+      assert_response :success
+      assert_template 'show.html.erb'
+      assert_not_nil assigns(:gantt)
+    end
+    
+    should "work without issue and version due dates" do
+      Issue.update_all("due_date = NULL")
+      Version.update_all("effective_date = NULL")
+      
+      get :show, :project_id => 1
+      assert_response :success
+      assert_template 'show.html.erb'
+      assert_not_nil assigns(:gantt)
     end
 
     should "work cross project" do
@@ -26,8 +45,20 @@ class GanttsControllerTest < ActionController::TestCase
       assert_response :success
       assert_template 'show.html.erb'
       assert_not_nil assigns(:gantt)
-      events = assigns(:gantt).events
-      assert_not_nil events
+      assert_not_nil assigns(:gantt).query
+      assert_nil assigns(:gantt).project
+    end
+
+    should "not disclose private projects" do
+      get :show
+      assert_response :success
+      assert_template 'show.html.erb'
+      
+      assert_tag 'a', :content => /eCookbook/
+      # Root private project
+      assert_no_tag 'a', {:content => /OnlineStore/}
+      # Private children of a public project
+      assert_no_tag 'a', :content => /Private child of eCookbook/
     end
 
     should "export to pdf" do
