@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.dirname(__FILE__) + '/../test_helper'
+require File.expand_path('../../test_helper', __FILE__)
 require 'groups_controller'
 
 # Re-raise errors caught by the controller.
@@ -54,7 +54,7 @@ class GroupsControllerTest < ActionController::TestCase
     assert_difference 'Group.count' do
       post :create, :group => {:lastname => 'New group'}
     end
-    assert_redirected_to 'groups'
+    assert_redirected_to '/groups'
   end
   
   def test_edit
@@ -65,14 +65,14 @@ class GroupsControllerTest < ActionController::TestCase
   
   def test_update
     post :update, :id => 10
-    assert_redirected_to 'groups'
+    assert_redirected_to '/groups'
   end
   
   def test_destroy
     assert_difference 'Group.count', -1 do
       post :destroy, :id => 10
     end
-    assert_redirected_to 'groups'
+    assert_redirected_to '/groups'
   end
   
   def test_add_users
