@@ -1,5 +1,5 @@
 
-require File.dirname(__FILE__) + '/../../../../../test_helper'
+require File.expand_path('../../../../../../test_helper', __FILE__)
 
 
 class FilesystemAdapterTest < ActiveSupport::TestCase
