@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.dirname(__FILE__) + '/../test_helper'
+require File.expand_path('../../test_helper', __FILE__)
 
 class MailHandlerTest < ActiveSupport::TestCase
   fixtures :users, :projects, 
@@ -25,15 +25,18 @@ class MailHandlerTest < ActiveSupport::TestCase
                    :roles,
                    :members,
                    :member_roles,
+                   :users,
                    :issues,
                    :issue_statuses,
                    :workflows,
                    :trackers,
                    :projects_trackers,
+                   :versions,
                    :enumerations,
                    :issue_categories,
                    :custom_fields,
                    :custom_fields_trackers,
+                   :custom_fields_projects,
                    :boards,
                    :messages
   
@@ -41,6 +44,7 @@ class MailHandlerTest < ActiveSupport::TestCase
   
   def setup
     ActionMailer::Base.deliveries.clear
+    Setting.notified_events = Redmine::Notifiable.all.collect(&:name)
   end
   
   def test_add_issue
@@ -50,14 +54,19 @@ class MailHandlerTest < ActiveSupport::TestCase
     assert issue.is_a?(Issue)
     assert !issue.new_record?
     issue.reload
+    assert_equal Project.find(2), issue.project
+    assert_equal issue.project.trackers.first, issue.tracker
     assert_equal 'New ticket on a given project', issue.subject
     assert_equal User.find_by_login('jsmith'), issue.author
-    assert_equal Project.find(2), issue.project
     assert_equal IssueStatus.find_by_name('Resolved'), issue.status
     assert issue.description.include?('Lorem ipsum dolor sit amet, consectetuer adipiscing elit.')
     assert_equal '2010-01-01', issue.start_date.to_s
     assert_equal '2010-12-31', issue.due_date.to_s
     assert_equal User.find_by_login('jsmith'), issue.assigned_to
+    assert_equal Version.find_by_name('alpha'), issue.fixed_version
+    assert_equal 2.5, issue.estimated_hours
+    assert_equal 30, issue.done_ratio
+    assert_equal [issue.id, 1, 2], [issue.root_id, issue.lft, issue.rgt]
     # keywords should be removed from the email body
     assert !issue.description.match(/^Project:/i)
     assert !issue.description.match(/^Status:/i)
@@ -66,6 +75,15 @@ class MailHandlerTest < ActiveSupport::TestCase
     assert_not_nil mail
     assert mail.subject.include?('New ticket on a given project')
   end
+  
+  def test_add_issue_with_default_tracker
+    # This email contains: 'Project: onlinestore'
+    issue = submit_email('ticket_on_given_project.eml', :issue => {:tracker => 'Support request'})
+    assert issue.is_a?(Issue)
+    assert !issue.new_record?
+    issue.reload
+    assert_equal 'Support request', issue.tracker.name
+  end
 
   def test_add_issue_with_status
     # This email contains: 'Project: onlinestore' and 'Status: Resolved'
@@ -152,7 +170,7 @@ class MailHandlerTest < ActiveSupport::TestCase
     assert !issue.new_record?
     issue.reload
     assert issue.watched_by?(User.find_by_mail('dlopper@somenet.foo'))
-    assert_equal 1, issue.watchers.size
+    assert_equal 1, issue.watcher_user_ids.size
   end
   
   def test_add_issue_by_unknown_user
@@ -195,6 +213,7 @@ class MailHandlerTest < ActiveSupport::TestCase
         assert issue.is_a?(Issue)
         assert issue.author.anonymous?
         assert !issue.project.is_public?
+        assert_equal [issue.id, 1, 2], [issue.root_id, issue.lft, issue.rgt]
       end
     end
   end
@@ -223,6 +242,34 @@ class MailHandlerTest < ActiveSupport::TestCase
     Role.anonymous.add_permission!(:add_issues)
     assert_equal false, submit_email('ticket_without_from_header.eml')
   end
+
+  def test_add_issue_with_invalid_attributes
+    issue = submit_email('ticket_with_invalid_attributes.eml', :allow_override => 'tracker,category,priority')
+    assert issue.is_a?(Issue)
+    assert !issue.new_record?
+    issue.reload
+    assert_nil issue.assigned_to
+    assert_nil issue.start_date
+    assert_nil issue.due_date
+    assert_equal 0, issue.done_ratio
+    assert_equal 'Normal', issue.priority.to_s
+    assert issue.description.include?('Lorem ipsum dolor sit amet, consectetuer adipiscing elit.')
+  end
+
+  def test_add_issue_with_localized_attributes
+    User.find_by_mail('jsmith@somenet.foo').update_attribute 'language', 'fr'
+    issue = submit_email('ticket_with_localized_attributes.eml', :allow_override => 'tracker,category,priority')
+    assert issue.is_a?(Issue)
+    assert !issue.new_record?
+    issue.reload
+    assert_equal 'New ticket on a given project', issue.subject
+    assert_equal User.find_by_login('jsmith'), issue.author
+    assert_equal Project.find(2), issue.project
+    assert_equal 'Feature request', issue.tracker.to_s
+    assert_equal 'Stock management', issue.category.to_s
+    assert_equal 'Urgent', issue.priority.to_s
+    assert issue.description.include?('Lorem ipsum dolor sit amet, consectetuer adipiscing elit.')
+  end
   
   def test_add_issue_with_japanese_keywords
     tracker = Tracker.create!(:name => '開発')
@@ -240,6 +287,7 @@ class MailHandlerTest < ActiveSupport::TestCase
   end
 
   def test_add_issue_should_send_email_notification
+    Setting.notified_events = ['issue_added']
     ActionMailer::Base.deliveries.clear
     # This email contains: 'Project: onlinestore'
     issue = submit_email('ticket_on_given_project.eml')
@@ -253,6 +301,7 @@ class MailHandlerTest < ActiveSupport::TestCase
     assert_equal User.find_by_login('jsmith'), journal.user
     assert_equal Issue.find(2), journal.journalized
     assert_match /This is reply/, journal.notes
+    assert_equal 'Feature request', journal.issue.tracker.name
   end
 
   def test_add_issue_note_with_attribute_changes
@@ -263,10 +312,12 @@ class MailHandlerTest < ActiveSupport::TestCase
     assert_equal User.find_by_login('jsmith'), journal.user
     assert_equal Issue.find(2), journal.journalized
     assert_match /This is reply/, journal.notes
+    assert_equal 'Feature request', journal.issue.tracker.name
     assert_equal IssueStatus.find_by_name("Resolved"), issue.status
     assert_equal '2010-01-01', issue.start_date.to_s
     assert_equal '2010-12-31', issue.due_date.to_s
     assert_equal User.find_by_login('jsmith'), issue.assigned_to
+    assert_equal "52.6", issue.custom_value_for(CustomField.find_by_name('Float field')).value
   end
 
   def test_add_issue_note_should_send_email_notification
@@ -276,6 +327,14 @@ class MailHandlerTest < ActiveSupport::TestCase
     assert_equal 1, ActionMailer::Base.deliveries.size
   end
   
+  def test_add_issue_note_should_not_set_defaults
+    journal = submit_email('ticket_reply.eml', :issue => {:tracker => 'Support request', :priority => 'High'})
+    assert journal.is_a?(Journal)
+    assert_match /This is reply/, journal.notes
+    assert_equal 'Feature request', journal.issue.tracker.name
+    assert_equal 'Normal', journal.issue.priority.name
+  end
+  
   def test_reply_to_a_message
     m = submit_email('message_reply.eml')
     assert m.is_a?(Message)
@@ -333,6 +392,38 @@ class MailHandlerTest < ActiveSupport::TestCase
       end
     end
 
+    context "with a single quoted reply (e.g. reply to a Redmine email notification)" do
+      setup do
+        Setting.mail_handler_body_delimiters = '--- Reply above. Do not remove this line. ---'
+      end
+
+      should "truncate the email at the delimiter with the quoted reply symbols (>)" do
+        journal = submit_email('issue_update_with_quoted_reply_above.eml')
+        assert journal.is_a?(Journal)
+        assert journal.notes.include?('An update to the issue by the sender.')
+        assert !journal.notes.match(Regexp.escape("--- Reply above. Do not remove this line. ---"))
+        assert !journal.notes.include?('Looks like the JSON api for projects was missed.')
+
+      end
+
+    end
+    
+    context "with multiple quoted replies (e.g. reply to a reply of a Redmine email notification)" do
+      setup do
+        Setting.mail_handler_body_delimiters = '--- Reply above. Do not remove this line. ---'
+      end
+
+      should "truncate the email at the delimiter with the quoted reply symbols (>)" do
+        journal = submit_email('issue_update_with_multiple_quoted_reply_above.eml')
+        assert journal.is_a?(Journal)
+        assert journal.notes.include?('An update to the issue by the sender.')
+        assert !journal.notes.match(Regexp.escape("--- Reply above. Do not remove this line. ---"))
+        assert !journal.notes.include?('Looks like the JSON api for projects was missed.')
+
+      end
+
+    end
+
     context "with multiple strings" do
       setup do
         Setting.mail_handler_body_delimiters = "---\nBREAK"
